"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * Return a function's source code in nicely spaced array format
 * @param {Function} func The function to examine
 * @return {string[]} function source code in an array, where each 'line' is an item
 */
exports.getFnAsArr = function (func) { return func.toString().split('\n'); };
exports.getFunctionSrcAsArray = exports.getFnAsArr;
/***************************************** LOOP UTILITIES *****************************************/
/**
 * Run given function N times, returning results as an array containing all N return vals
 * @param {number} n Number of times to run given function
 * @param {Function} func Function to repeatedly run
 * @return {Array<any>} Array containing function return values
 */
exports.loopN = function (n, func) {
    var retArr = [];
    for (var i = 0; i < n; i++)
        retArr.push(func());
    return retArr;
};
/**
 * Run given function 2X, returning results as an array containing both return vals
 * @param {Function} func Function to run 2X
 * @return {T[]} Array of return values (one from each run of the function)
 */
exports.loop2 = function (func) { return exports.loopN(2, func); };
/**
 * Run given function 3X, returning results as an array containing all 3 return vals
 * @param {Function} func Function to run 3X
 * @return {T[]} Array of return values (one from each run of the function)
 */
exports.loop3 = function (func) { return exports.loopN(3, func); };
/**
 * Run given function 4X, returning results as an array containing all 4 return vals
 * @param {Function} func Function to run 4X
 * @return {T[]} Array of return values (one from each run of the function)
 */
exports.loop4 = function (func) { return exports.loopN(4, func); };
/**
 * Run given function 5X, returning results as an array containing all 5 return vals
 * @param {Function} func Function to run 5X
 * @return {T[]} Array of return values (one from each run of the function)
 */
exports.loop5 = function (func) { return exports.loopN(5, func); };
/**
 * Rough method to list a function's arguments/parameters (untyped)
 * @param {Function} func Function to get the arguments/params of
 * @return {string[]} List of argument names in string form e.g.: ['id', 'name', age']
 */
exports.getArgNames = function (func) {
    var args = func
        .toString()
        .split('\n')
        .join('')
        .split(/[\(\)]/g)[1]
        .split(/ *, */g);
    return args.length === 1 && args[0] === '' ? [] : args;
};
exports.getArgsFromFunc = exports.getArgNames;
exports.getArgs = exports.getArgNames;
/****************************************** CONDITIONALS ******************************************/
/**
 * Function-based switch expression
 *
 * Any odd number of arguments can be given, where for each pair of args, the
 * 1st arg is a condition (which passes if truthy), and the 2nd is the value
 * returned if the condition passes
 * If no conditions pass, the final arg given (default val) is returned
 * If no final arg is given, it instead throws an error
 *
 * If using prettier, it's useful to place prettier-ignore directive above usage, for readability
 *
 * Example: If size is 'tiny', returns 12; if size is 'small', returns 14; otherwise, returns 20:
 *     // prettier-ignore
 *     switchExpr(size === 'tiny',  12,
 *                size === 'small', 14,
 *                                  20);
 *
 * Each pair of arguments:
 *     @param {boolean|any} cond Condition to check for truthiness
 *     @param {any} val Value returned if the test condition is truthy
 * Final argument:
 *     @param {any} defVal Value returned if no test conditions are met
 *
 * @return {any} 2nd item in a pair if the 1st item was truthy, or default
 *               value if none match
 */
function switchExpr(cond, val) {
    var condValPairsAndOrDefVal = [];
    for (var _i = 2; _i < arguments.length; _i++) {
        condValPairsAndOrDefVal[_i - 2] = arguments[_i];
    }
    if (cond)
        return val;
    if (condValPairsAndOrDefVal.length === 1)
        return condValPairsAndOrDefVal[0];
    while (condValPairsAndOrDefVal.length > 1) {
        if (condValPairsAndOrDefVal[0])
            return condValPairsAndOrDefVal[1];
        exports.loop2(function () { return condValPairsAndOrDefVal.shift(); });
    }
    if (condValPairsAndOrDefVal.length === 0) {
        throw new Error('No matching val found. To avoid throwing in this scenario, pass args to consSwitch' +
            'in pairs, where #1 is the test, and #2 is the return val if test is truthy - then ' +
            'follow them with a final "else" value to return if no other tests are truthy');
    }
    return condValPairsAndOrDefVal[0];
}
exports.switchExpr = switchExpr;
exports.condSwitch = switchExpr;
/**
 * DEPRECATED
 * Deprecated form of switchExpr - use switchExpr instead
 */
function condSwitch(cond, val) {
    var condValPairsAndOrDefVal = [];
    for (var _i = 2; _i < arguments.length; _i++) {
        condValPairsAndOrDefVal[_i - 2] = arguments[_i];
    }
    console.warn("WARNING: condSwitch is deprecated, use switchExpr instead");
    return switchExpr.apply(void 0, [cond, val].concat(condValPairsAndOrDefVal));
}
function throttle(cb, wait, immediate) {
    if (immediate === void 0) { immediate = true; }
    var blocked = false;
    var retFn = function throttledFn() {
        var fnArgs = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            fnArgs[_i] = arguments[_i];
        }
        if (!blocked) {
            blocked = true;
            setTimeout(function () {
                blocked = false;
                if (!immediate)
                    return cb.apply(void 0, fnArgs);
            }, wait);
            if (immediate)
                cb.apply(void 0, fnArgs);
        }
    };
    // Assign cb's prototype to retFn
    retFn.prototype = Object.create(cb.prototype);
    // Hoist keys from cb onto retFn
    Object.keys(cb).forEach(function (k) { return (retFn[k] = cb[k]); });
    return retFn;
}
exports.throttle = throttle;
/**
 * Wrap function [cb] to make it run after (and only after) it stops being invoked for at
 * least [wait] ms. Also run initially if [immediate] is true, trigger function
 * at the beginning, instead of at the end.
 */
exports.debounce = function (cb, wait, immediate) {
    if (immediate === void 0) { immediate = false; }
    var timeout;
    var retFn = function debouncedFn() {
        var fnArgs = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            fnArgs[_i] = arguments[_i];
        }
        var self = this;
        clearTimeout(timeout);
        var runAfterWait = function () {
            timeout = null;
            if (!immediate)
                cb.apply(self, fnArgs);
        };
        var runImmediately = immediate && !timeout;
        timeout = setTimeout(runAfterWait, wait);
        if (runImmediately)
            cb.apply(self, fnArgs);
    };
    /*----- Make returned function behave like original -----*/
    // Assign cb's prototype to retFn
    retFn.prototype = Object.create(cb.prototype);
    // Hoist keys from cb onto retFn
    Object.keys(cb).forEach(function (k) { return (retFn[k] = cb[k]); });
    return retFn;
};
/**
 * Run all functions in given array [arr], optionally with each argument after
 * the 1st as args passed to each function; return results in an array
 */
exports.runAll = function (arr) {
    var args = [];
    for (var _i = 1; _i < arguments.length; _i++) {
        args[_i - 1] = arguments[_i];
    }
    var res = [];
    arr.forEach(function (fn) { return res.push(fn.apply(void 0, args)); });
    return res;
};
//# sourceMappingURL=function.js.map