/**************************************************************************************************
 *
 *       @file ./file.ts
 *
 *       NodeJS-only helpers / utils for file & filesystem handling
 *
 */
/******************************************** EXPORTS *********************************************/
/**
 * Determine if inode (file, directory, socket, etc) at absolute path is a
 * directory
 *
 * [SYNCHRONOUS]
 *
 * @param {string} fileOrDirPath File system object being checked
 * @return {boolean} true if given file system object is a directory
 *                   false if it's not (e.g. it's a file or socket)
 */
export declare const isDir: (fileOrDirPath: string) => boolean;
/**
 * Is the given path an absolute path?
 *
 * @param {string} newPath Path to determine if absolute
 * @return {boolean} True if path is absolute
 */
export declare const isAbsPath: (newPath: string) => boolean;
/**
 * Return path relative to root of project mad-utils is installed in
 * (Root of project = directory with package.json)
 *
 * If mad-utils is standalone (for development), return path relative to
 * root of mad-utils
 *
 * Example:
 *     // Project directory: `/projs/my-app`:
 *     pathFromRoot(`src/index.js`);
 *     // => `/projs/my-app/src/index.js`
 *
 * @param {string} filePathFromRoot File path to return relative to the root
 * @return {string} Given file path relative to project root path, or project path if
 *                  relative path arg not provided
 */
export declare const pathFromRoot: (filePathFromRoot?: string) => string;
/**
 * Returns true if the given filename was run as a script
 *
 * @param {string} filePathOrName Name of file (or path to file) where the
 *                                command was run from
 * @return {boolean} true if file with given name was run as a script
 */
export declare const wasRunAsScript: (filePathOrName: string, argv?: string[], TAG?: string) => boolean;
export declare type StrOrRegexp = string | RegExp;
/**
 * Replace matching location in given file
 *
 * Text in given file that matches the provided regex or string gets replaced
 * with the provided replacement text
 *
 * [SYNCHRONOUS]
 *
 * @param {string} filePath File to perform replacement in
 * @param {string|RegExp} findStrOrRE Match to perform against content of the
 *                                    file at filePath
 * @param {string} replace Text to replace the matching text with
 *
 * @return {string} File content after the replacement
 */
export declare function replaceInFile(filePath: string, findStrOrRE: StrOrRegexp, replace: string): string;
/**
 * Traverse given folder & return list of all .js inodes it contains
 * [SYNCHRONOUS]
 *
 * @param {string} dir - absolute path to directory.
 * @param {boolean} excludeMin - If true, exclude all .min.js files.
 * @return {string[]} List of all non-minified .js inodes in given directory.
 */
export declare const getJsFilesInDir: (dir: string, excludeMin?: boolean) => string[];
/**
 * Search a given directory for an inode (file or folder) with the given name
 *
 * [SYNCHRONOUS]
 *
 * @param {string} dir Absolute path to directory to check for file of given name
 * @param {string} filename name of inode to look for in directory
 * @return {boolean} Return true if given filename is present in folder at given path
 */
export declare const isFileInDir: (dir: string, filename: string) => boolean;
