"use strict";
/**************************************************************************************************
 *
 *       @file ./file.ts
 *
 *       NodeJS-only helpers / utils for file & filesystem handling
 *
 */
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
/************************************** THIRD-PARTY MODULES ***************************************/
var path_1 = __importDefault(require("path"));
var app_root_path_1 = require("app-root-path");
var env_var_helpers_1 = require("env-var-helpers");
var fs_extra_promise_1 = require("fs-extra-promise");
/**************************************** PROJECT MODULES *****************************************/
var string_1 = require("../string");
/******************************************** LOGGING *********************************************/
var shared_1 = require("mad-logs/lib/shared");
var log = shared_1.logFactory("mad-utils -> file.ts", shared_1.Styles.cult);
/******************************************** EXPORTS *********************************************/
/**
 * Determine if inode (file, directory, socket, etc) at absolute path is a
 * directory
 *
 * [SYNCHRONOUS]
 *
 * @param {string} fileOrDirPath File system object being checked
 * @return {boolean} true if given file system object is a directory
 *                   false if it's not (e.g. it's a file or socket)
 */
exports.isDir = function (fileOrDirPath) {
    try {
        return !!fs_extra_promise_1.lstatSync(fileOrDirPath).isDirectory();
    }
    catch (e) {
        return false;
    }
};
/**
 * Is the given path an absolute path?
 *
 * @param {string} newPath Path to determine if absolute
 * @return {boolean} True if path is absolute
 */
exports.isAbsPath = function (newPath) { return !!newPath.match(/^\//); };
/**
 * Return path relative to root of project mad-utils is installed in
 * (Root of project = directory with package.json)
 *
 * If mad-utils is standalone (for development), return path relative to
 * root of mad-utils
 *
 * Example:
 *     // Project directory: `/projs/my-app`:
 *     pathFromRoot(`src/index.js`);
 *     // => `/projs/my-app/src/index.js`
 *
 * @param {string} filePathFromRoot File path to return relative to the root
 * @return {string} Given file path relative to project root path, or project path if
 *                  relative path arg not provided
 */
exports.pathFromRoot = function (filePathFromRoot) {
    if (filePathFromRoot === void 0) { filePathFromRoot = ""; }
    return path_1.default.join(app_root_path_1.path, filePathFromRoot);
};
/**
 * Returns true if the given filename was run as a script
 *
 * @param {string} filePathOrName Name of file (or path to file) where the
 *                                command was run from
 * @return {boolean} true if file with given name was run as a script
 */
exports.wasRunAsScript = function (filePathOrName, argv, TAG) {
    if (argv === void 0) { argv = process.argv; }
    if (TAG === void 0) { TAG = ""; }
    var findFilename = new RegExp(path_1.default.basename(filePathOrName).replace(".", "."));
    var wasScript = !!findFilename.exec(argv[1]);
    if (wasScript && env_var_helpers_1.isVerbose) {
        console.log((TAG ? TAG + ' ' : '') + "Running " + filePathOrName + " as a standalone script...");
    }
    return wasScript;
};
/**
 * Replace matching location in given file
 *
 * Text in given file that matches the provided regex or string gets replaced
 * with the provided replacement text
 *
 * [SYNCHRONOUS]
 *
 * @param {string} filePath File to perform replacement in
 * @param {string|RegExp} findStrOrRE Match to perform against content of the
 *                                    file at filePath
 * @param {string} replace Text to replace the matching text with
 *
 * @return {string} File content after the replacement
 */
function replaceInFile(filePath, findStrOrRE, replace) {
    var fileData = fs_extra_promise_1.readFileSync(filePath).toString();
    // Hack required to make typings happy
    var cleanfileData = typeof findStrOrRE === "string"
        ? fileData.replace(findStrOrRE, replace)
        : fileData.replace(findStrOrRE, replace);
    fs_extra_promise_1.writeFileSync(filePath, cleanfileData, { encoding: "utf8" });
    log.silly("replaceInFile: new " + filePath + " contents:", cleanfileData);
    return cleanfileData;
}
exports.replaceInFile = replaceInFile;
/**
 * Traverse given folder & return list of all .js inodes it contains
 * [SYNCHRONOUS]
 *
 * @param {string} dir - absolute path to directory.
 * @param {boolean} excludeMin - If true, exclude all .min.js files.
 * @return {string[]} List of all non-minified .js inodes in given directory.
 */
exports.getJsFilesInDir = function (dir, excludeMin) {
    if (excludeMin === void 0) { excludeMin = true; }
    return fs_extra_promise_1.readdirSync(dir)
        .filter(string_1.endsInDotJs)
        .filter(excludeMin ? string_1.isNonMinFile : function () { return true; });
};
/**
 * Search a given directory for an inode (file or folder) with the given name
 *
 * [SYNCHRONOUS]
 *
 * @param {string} dir Absolute path to directory to check for file of given name
 * @param {string} filename name of inode to look for in directory
 * @return {boolean} Return true if given filename is present in folder at given path
 */
exports.isFileInDir = function (dir, filename) {
    return !!fs_extra_promise_1.readdirSync(dir).find(function (file) { return file === filename; });
};
//# sourceMappingURL=file.js.map