"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/*------------------------------------------- IMPORTS --------------------------------------------*/
var types_iso_1 = require("./types-iso");
exports.isInt = types_iso_1.isInt;
exports.isInteger = types_iso_1.isInteger;
exports.isIntegerLike = types_iso_1.isIntegerLike;
exports.isNumberLike = types_iso_1.isNumberLike;
exports.isNumLike = types_iso_1.isNumLike;
var uuid_1 = require("uuid");
/*-------------------------------------------- RANDOM --------------------------------------------*/
/**
 * Randomly get HEADS or TAILS. 50-50 chance of either.
 * @return {'HEADS'|'TAILS'} 'HEADS' or 'TAILS' - at random.
 */
exports.coinFlip = function () { return (Math.random() < 0.5 ? 'HEADS' : 'TAILS'); };
/**
 * Randomly get a number from 1 to 6.
 * @return {number} 1, 2, 3, 4, 5, or 6 - at random.
 */
exports.diceRoll6Sided = function () {
    var num = Math.random();
    if (num <= 0.16666666666666666)
        return 1;
    if (num <= 0.33333333333333333)
        return 2;
    if (num <= 0.5)
        return 3;
    if (num <= 0.66666666666666666)
        return 4;
    if (num <= 0.83333333333333333)
        return 5;
    return 6;
};
// TODO test getRandomInt
/**
 * Generate a random integer between (and including) given min & max values
 *
 * @param {number} min Lowest possible number that can be generated
 * @param {number} max Highest possible number that can be generated
 *
 * @return {number} Randomly selected integer between given min & max values
 */
exports.getRandomInt = function (min, max) {
    var minInt = Math.ceil(min);
    var maxInt = Math.floor(max);
    return Math.round(Math.random() * (maxInt - minInt)) + minInt;
};
/*--------------------------------------------- UUID ---------------------------------------------*/
var uuidBase = function () { return uuid_1.v4(); };
/**
 * Generate full UUID with no dashes e.g. `505BB6B57D684C2488DD1522B34CF539`
 * @return {string} Generate a UUID without any dashes
 */
var noDashes = function () {
    return uuidBase()
        .split('-')
        .join('');
};
/**
 * Generate 16-char UUID e.g. `7JX4L2Z3J44OQ9C5`
 * @return {string} Randomly generated sequence 16 characters long
 */
var len16 = function () { return noDashes().slice(0, 16); };
/**
 * Generate 8-char UUID e.g. `0E8526U3`
 * @return {string} Randomly generated sequence 8 characters long
 */
var len8 = function () { return uuidBase().split('-')[0]; };
/**
 * Generate 6-char UUID e.g. `AB790517`
 * @return {string} Randomly generated sequence 6 characters long
 */
var len6 = function () { return len8().slice(0, -2); };
/**
 * Generate 4-char UUID e.g. `V0S1`
 * @return {string} Randomly generated sequence 4 characters long
 */
var len4 = function () { return len8().slice(0, -4); };
/**
 * Export UUID
 * If uuid itself is run as a function, it generates a UUID
 * uuid object contains child functions uuid.len6, uuid.len8, & uuid.noDashes
 */
exports.uuid = Object.assign(uuidBase, { noDashes: noDashes, len4: len4, len6: len6, len8: len8, len16: len16 });
/**
 * Regex for detecting UUID
 */
exports.uuidRegex = /^[0-9A-F]{8}-[0-9A-F]{4}-[4][0-9A-F]{3}-[89AB][0-9A-F]{3}-[0-9A-F]{12}$/gi;
/**
 * Return true if given value is a UUID (v4)
 */
exports.isUUID = function (value) {
    return typeof value === "string" ? !!value.match(exports.uuidRegex) : false;
};
/*-------------------------------------------- RANGE ---------------------------------------------*/
/**
 * Create range between given numbers, with the provided interval.
 * @param {number} start Number to start at.
 * @param {number} end   Number to end at.
 * @param {number} increment Amount to increase by with each subsequent number. {DEF: 1} {OPT}
 * @return {Array<number>} Array containing all numbers in the interval.
 */
exports.createRangeArray = function (start, end, increment) {
    if (start === void 0) { start = 0; }
    if (increment === void 0) { increment = 1; }
    // If the first and last values are equal, return that value wrapped in an array
    if (end === start)
        return [start];
    if (increment === 0)
        throw new Error('Cannot create a range array with 0 as the increment');
    var arr = [];
    if (end > start && Math.abs(increment) === increment) {
        for (var i = start; i <= end; i += increment)
            arr.push(i);
    }
    else if (start > end && Math.abs(increment) === increment) {
        for (var i = end; i <= start; i += increment)
            arr.push(i);
        arr.reverse();
    }
    else if (end > start && Math.abs(increment) !== increment) {
        for (var i = end; i >= start; i += increment)
            arr.push(i);
        arr.reverse();
    }
    else if (start > end && Math.abs(increment) !== increment) {
        for (var i = start; i >= end; i += increment)
            arr.push(i);
    }
    return arr;
};
//# sourceMappingURL=number.js.map